==> jquery-mediaplayer-0.2.1.tgz: package/example/source-photo.php <==
<?php

$media = [];

$item = new stdClass;
$item->type = 'image';
$item->thumbnail = 'http://placehold.it/180x120?text=1';
$item->sourceset = [
        'default'   => 'http://placehold.it/720x480?text=default',
        'small'     => 'http://placehold.it/720x480?text=small',
        'medium'    => 'http://placehold.it/720x480?text=medium',
        'large'     => 'http://placehold.it/720x480?text=large',
        'original'  => 'http://placehold.it/720x480?text=original'
];
$item->meta = [
        'id' => 2859,
        'title' => 'Onze Lieve Vrouw Tenhemelopnemning in Einighausen',
        'description' => 'Einighausen-Kerk van Onze Lieve Vrouw ten Hemelopneming. De Gertrudiskerk in Maarheeze is gebouwd naar het voorbeeld van deze kerk van Onze Lieve Vrouw Tenhemelopnemning te Einighausen. In grote lijn lijken de kerken sterk op elkaar. Echter in veel details zie je de verschillen. De kerk in Einighausen is gebouwd naar een ontwerp van de architect Caspar Franssen.'
];
$media[] = $item;

$item = new stdClass;
$item->type = 'image';
$item->thumbnail = 'http://placehold.it/180x120?text=2';
$item->sourceset = [
    'default'   => 'http://placehold.it/720x480?text=default-2',
    'small'     => 'http://placehold.it/720x480?text=small-2',
    'medium'    => 'http://placehold.it/720x480?text=medium-2',
    'large'     => 'http://placehold.it/720x480?text=large-2',
    'original'  => 'http://placehold.it/720x480?text=original-2'
];
$item->meta = [
    'id' => 2861,
    'title' => 'Boogramen',
    'description' => 'Einighausen-Kerk van Onze Lieve Vrouw ten Hemelopneming. De Gertrudiskerk in Maarheeze is gebouwd naar het voorbeeld van deze kerk van Onze Lieve Vrouw Tenhemelopnemning te Einighausen. In grote lijn lijken de kerken sterk op elkaar. Echter in veel details zie je de verschillen. De kerk in Einighausen is gebouwd naar een ontwerp van de architect Caspar Franssen.'
];
$media[] = $item;

$item = new stdClass;
$item->type = 'image';
$item->thumbnail = 'http://placehold.it/180x120?text=3';
$item->sourceset = [
    'default'   => 'http://placehold.it/720x480?text=default-3',
    'small'     => 'http://placehold.it/720x480?text=small-3',
    'medium'    => 'http://placehold.it/720x480?text=medium-3',
    'large'     => 'http://placehold.it/720x480?text=large-3',
    'original'  => 'http://placehold.it/720x480?text=original-3'
];
$item->meta = [
    'id' => 2869,
    'title' => 'Fronttorens',
    'description' => 'Einighausen-Kerk van Onze Lieve Vrouw ten Hemelopneming. De Gertrudiskerk in Maarheeze is gebouwd naar het voorbeeld van deze kerk van Onze Lieve Vrouw Tenhemelopnemning te Einighausen. In grote lijn lijken de kerken sterk op elkaar. Echter in veel details zie je de verschillen. De kerk in Einighausen is gebouwd naar een ontwerp van de architect Caspar Franssen.'
];
$media[] = $item;

echo json_encode($media);
exit;

==> jquery-mediaplayer-0.3.6.tgz: package/example/source-photo.php <==
<?php

$media = [];

$item = new stdClass;
$item->type = 'image';
$item->thumbnail = 'http://placehold.it/180x120?text=1';
$item->sourceset = [
        'default'   => 'http://placehold.it/720x480?text=default',
        'small'     => 'http://placehold.it/720x480?text=small',
        'medium'    => 'image.php?file=example.png&wait=5',
        'large'     => 'http://placehold.it/720x480?text=large',
        'original'  => 'image.php?file=example.png&original'
];
$item->meta = [
        'id' => 2859,
        'title' => 'Onze Lieve Vrouw Tenhemelopnemning in Einighausen',
        'description' => 'Einighausen-Kerk van Onze Lieve Vrouw ten Hemelopneming. De Gertrudiskerk in Maarheeze is gebouwd naar het voorbeeld van deze kerk van Onze Lieve Vrouw Tenhemelopnemning te Einighausen. In grote lijn lijken de kerken sterk op elkaar. Echter in veel details zie je de verschillen. De kerk in Einighausen is gebouwd naar een ontwerp van de architect Caspar Franssen.'
];
$media[] = $item;

$item = new stdClass;
$item->type = 'image';
$item->thumbnail = 'http://placehold.it/180x120?text=2';
$item->sourceset = [
    'default'   => 'http://placehold.it/720x480?text=default-2',
    'small'     => 'http://placehold.it/720x480?text=small-2',
    'medium'    => 'image.php?file=example.png&wait=10',
    'large'     => 'http://placehold.it/720x480?text=large-2',
    'original'  => 'http://placehold.it/720x480?text=original-2'
];
$item->meta = [
    'id' => 2861,
    'title' => 'Boogramen',
    'description' => 'Einighausen-Kerk van Onze Lieve Vrouw ten Hemelopneming. De Gertrudiskerk in Maarheeze is gebouwd naar het voorbeeld van deze kerk van Onze Lieve Vrouw Tenhemelopnemning te Einighausen. In grote lijn lijken de kerken sterk op elkaar. Echter in veel details zie je de verschillen. De kerk in Einighausen is gebouwd naar een ontwerp van de architect Caspar Franssen.'
];
$media[] = $item;

$item = new stdClass;
$item->type = 'image';
$item->thumbnail = 'http://placehold.it/180x120?text=3';
$item->sourceset = [
    'default'   => 'http://placehold.it/720x480?text=default-3',
    'small'     => 'http://placehold.it/720x480?text=small-3',
    'medium'    => 'image.php?file=example.png&wait=6',
    'large'     => 'http://placehold.it/720x480?text=large-3',
    'original'  => 'http://placehold.it/720x480?text=original-3'
];
$item->meta = [
    'id' => 2869,
    'title' => 'Fronttorens',
    'description' => 'Einighausen-Kerk van Onze Lieve Vrouw ten Hemelopneming. De Gertrudiskerk in Maarheeze is gebouwd naar het voorbeeld van deze kerk van Onze Lieve Vrouw Tenhemelopnemning te Einighausen. In grote lijn lijken de kerken sterk op elkaar. Echter in veel details zie je de verschillen. De kerk in Einighausen is gebouwd naar een ontwerp van de architect Caspar Franssen.'
];
$media[] = $item;

echo json_encode($media);
exit;
